commit-gnuradio
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Commit-gnuradio] [gnuradio] 108/148: renamed tics to ticks to be more p


From: git
Subject: [Commit-gnuradio] [gnuradio] 108/148: renamed tics to ticks to be more pc
Date: Mon, 15 Aug 2016 00:47:31 +0000 (UTC)

This is an automated email from the git hooks/post-receive script.

nwest pushed a commit to annotated tag old_usrp_devel_udp
in repository gnuradio.

commit 39f9c9a8efa1aea699f9ec97c9c1a728b016e940
Author: Josh Blum <address@hidden>
Date:   Wed Dec 23 10:13:25 2009 -0800

    renamed tics to ticks to be more pc
---
 usrp2/firmware/apps/txrx.c                | 12 ++++++------
 usrp2/firmware/include/usrp2_eth_packet.h |  2 +-
 usrp2/firmware/lib/memory_map.h           |  4 ++--
 usrp2/include/usrp2/usrp2.h               |  4 ++--
 usrp2/lib/usrp2_impl.cc                   |  2 +-
 5 files changed, 12 insertions(+), 12 deletions(-)

diff --git a/usrp2/firmware/apps/txrx.c b/usrp2/firmware/apps/txrx.c
index 2528bd1..cd6666a 100644
--- a/usrp2/firmware/apps/txrx.c
+++ b/usrp2/firmware/apps/txrx.c
@@ -123,7 +123,7 @@ u2_mac_addr_t host_mac_addr;
 static bool         streaming_p = false;
 static unsigned int streaming_items_per_frame = 0;
 static uint32_t     time_secs = TIME_NOW;
-static uint32_t     time_tics = TIME_NOW;
+static uint32_t     time_ticks = TIME_NOW;
 static int          streaming_frame_count = 0;
 #define FRAMES_PER_CMD 1000
 
@@ -156,20 +156,20 @@ restart_streaming(void)
 
   sr_rx_ctrl->cmd =
     MK_RX_CMD(FRAMES_PER_CMD * streaming_items_per_frame,
-    (time_tics==TIME_NOW)?1:0, 1);  // conditionally set "now" bit, set 
"chain" bit
+    (time_ticks==TIME_NOW)?1:0, 1);  // conditionally set "now" bit, set 
"chain" bit
 
   // kick off the state machine
   dbsm_start(&dsp_rx_sm);
 
   sr_rx_ctrl->time_secs = time_secs;
-  sr_rx_ctrl->time_tics = time_tics;           // enqueue first of two commands
+  sr_rx_ctrl->time_ticks = time_ticks;         // enqueue first of two commands
 
   // make sure this one and the rest have the "now" and "chain" bits set.
   sr_rx_ctrl->cmd =
     MK_RX_CMD(FRAMES_PER_CMD * streaming_items_per_frame, 1, 1);
 
   sr_rx_ctrl->time_secs = 0;
-  sr_rx_ctrl->time_tics = 0;           // enqueue second command
+  sr_rx_ctrl->time_ticks = 0;          // enqueue second command
 }
 
 void
@@ -195,7 +195,7 @@ start_rx_streaming_cmd(const u2_mac_addr_t *host, 
op_start_rx_streaming_t *p)
 
   streaming_items_per_frame = p->items_per_frame;
   time_secs = p->time_secs;
-  time_tics = p->time_tics;
+  time_ticks = p->time_ticks;
   restart_streaming();
 }
 
@@ -252,7 +252,7 @@ fw_sets_seqno_inspector(dbsm_t *sm, int buf_this)   // 
returns false
   if (streaming_p && --streaming_frame_count == 0){
     streaming_frame_count = FRAMES_PER_CMD;
     sr_rx_ctrl->time_secs = 0;
-    sr_rx_ctrl->time_tics = 0;
+    sr_rx_ctrl->time_ticks = 0;
   }
 
   return false;                // we didn't handle the packet
diff --git a/usrp2/firmware/include/usrp2_eth_packet.h 
b/usrp2/firmware/include/usrp2_eth_packet.h
index 2a16916..231f9d2 100644
--- a/usrp2/firmware/include/usrp2_eth_packet.h
+++ b/usrp2/firmware/include/usrp2_eth_packet.h
@@ -186,7 +186,7 @@ typedef struct {
   uint8_t      mbz;
   uint32_t     items_per_frame;  // # of 32-bit data items; MTU=1500: [9,371]
   uint32_t     time_secs;
-  uint32_t     time_tics;
+  uint32_t     time_ticks;
 } _AL4 op_start_rx_streaming_t;
 
 typedef struct {
diff --git a/usrp2/include/usrp2/usrp2.h b/usrp2/include/usrp2/usrp2.h
index 5246c79..e5bb3b0 100644
--- a/usrp2/include/usrp2/usrp2.h
+++ b/usrp2/include/usrp2/usrp2.h
@@ -55,10 +55,10 @@ namespace usrp2 {
    */
   typedef struct time_spec{
       uint32_t secs;
-      uint32_t tics;
+      uint32_t ticks;
       time_spec(void){
         secs = ~0;
-        tics = ~0;
+        ticks = ~0;
       }
   } time_spec_t;
 
diff --git a/usrp2/lib/usrp2_impl.cc b/usrp2/lib/usrp2_impl.cc
index 9666f8d..430f484 100644
--- a/usrp2/lib/usrp2_impl.cc
+++ b/usrp2/lib/usrp2_impl.cc
@@ -428,7 +428,7 @@ namespace usrp2 {
       cmd.op.rid = d_next_rid++;
       cmd.op.items_per_frame = htonl(items_per_frame);
       cmd.op.time_secs = time_spec->secs;
-      cmd.op.time_tics = time_spec->tics;
+      cmd.op.time_ticks = time_spec->ticks;
       cmd.eop.opcode = OP_EOP;
       cmd.eop.len = sizeof(cmd.eop);
 



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/usrp2/firmware/lib/memory_map.h b/usrp2/firmware/lib/memory_map.h
index 8aa21fd..be30949 100644
--- a/usrp2/firmware/lib/memory_map.h
+++ b/usrp2/firmware/lib/memory_map.h
@@ -453,10 +453,10 @@ typedef struct {
 // --- VITA RX CTRL regs ---
 typedef struct {
   // The following 3 are logically a single command register.
   // They are clocked into the underlying fifo when time_tics is written.
   volatile uint32_t    cmd;            // {now, chain, num_samples(30)
   volatile uint32_t    time_secs;
-  volatile uint32_t    time_tics;
+  volatile uint32_t    time_ticks;
 
   volatile uint32_t    clear_overrun;  // write anything to clear overrun
   volatile uint32_t    vrt_header;     // word 0 of packet.  FPGA fills in 
@@ -453,10 +453,10 @@ typedef struct {
 typedef struct {
   // The following 3 are logically a single command register.
-  // They are clocked into the underlying fifo when time_tics is written.
+  // They are clocked into the underlying fifo when time_ticks is written.
   volatile uint32_t    cmd;            // {now, chain, num_samples(30)
   volatile uint32_t    time_secs;
packet counter